const {
  dataApi: { ProjectApi },
  i18n,
  addonEvent,
  isDarkMode,
  ClientAddonApi,
  http
} = window.top.HPM_CLI_UI;

const projectApi = new ProjectApi();
const pluginName = '@ohos/hpm_cli_plugin_notice';
const NOTICE_NAME = 'Third Party Open Source Notice';

const registI18nResource = () => {
  const clientAddonApi = new ClientAddonApi();
  const zh_CN = {
    notice: "通告内容",
    notFound: `找不到对应的文件：${NOTICE_NAME}`
  }

  const en = {
    notice: "Notice",
    notFound: `Cannot found file: ${NOTICE_NAME}`
  }

  clientAddonApi.addLocalization('zh_CN', zh_CN, { pluginName });
  clientAddonApi.addLocalization('en', en, { pluginName });
}



const render = () => {
  const container = document.getElementById('pre');
  http.get(`/resource/@ohos/hpm_cli_plugin_notice/${NOTICE_NAME}`).then((data) => {
    if (data) {
      container.innerHTML = data;
    }
  }).catch((error) => {
    if (error && error.message && error.message.includes("no such file or directory")) {
      container.innerHTML = i18n.t(`${pluginName}.notFound`);
    } else {
      container.innerHTML = error && error.message;
    }
  });
  const htmlElm = document.getElementsByTagName('html')[0];
  isDarkMode ? htmlElm.classList.add('dark-mode') : htmlElm.classList.remove('dark-mode')
}

addonEvent.subscribe('localeChange', () => {
  // 更新视图
  render();
}, true)

addonEvent.subscribe('themeChange', data => {
  document.getElementsByTagName('html')[0].className = data.isDarkMode ? 'dark-mode' : ''
}, true)

addonEvent.subscribe('addonLoaded', () => {
  render();
}, true)

registI18nResource();
